from __future__ import annotations

from django.apps import AppConfig


class DjangoNh3AppConfig(AppConfig):
    name = "django_nh3"
    verbose_name = "django-nh3"

    def ready(self) -> None:
        from . import checks  # noqa: F401
